Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2248)

Unified Diff: content/renderer/media/media_stream_audio_processor.h

Issue 2103483002: Add UMA stats for AEC filter divergence metric. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed unit test. Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/renderer/media/media_stream_audio_processor.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/media/media_stream_audio_processor.h
diff --git a/content/renderer/media/media_stream_audio_processor.h b/content/renderer/media/media_stream_audio_processor.h
index 7cf9af023ec7ad302320b9d351be7cee196bc45f..8b0c0943a464be3020aef98f2a7ff0a6fdfbecd6 100644
--- a/content/renderer/media/media_stream_audio_processor.h
+++ b/content/renderer/media/media_stream_audio_processor.h
@@ -153,6 +153,9 @@ class CONTENT_EXPORT MediaStreamAudioProcessor :
bool key_pressed,
float* const* output_ptrs);
+ // Update AEC stats. Called on the main render thread.
+ void UpdateAecStats();
+
// Cached value for the render delay latency. This member is accessed by
// both the capture audio thread and the render audio thread.
base::subtle::Atomic32 render_delay_ms_;
@@ -190,13 +193,17 @@ class CONTENT_EXPORT MediaStreamAudioProcessor :
// Used to DCHECK that some methods are called on the render audio thread.
base::ThreadChecker render_thread_checker_;
+ // Message loop for the main render thread. We're assuming that we're created
+ // on the main render thread.
+ base::MessageLoop* main_thread_message_loop_;
+
// Flag to enable stereo channel mirroring.
bool audio_mirroring_;
+ // Typing detector. |typing_detected_| is used to show the result of typing
+ // detection. It can be accessed by the capture audio thread and by the
+ // libjingle thread which calls GetStats().
std::unique_ptr<webrtc::TypingDetection> typing_detector_;
- // This flag is used to show the result of typing detection.
- // It can be accessed by the capture audio thread and by the libjingle thread
- // which calls GetStats().
base::subtle::Atomic32 typing_detected_;
// Communication with browser for AEC dump.
@@ -205,8 +212,8 @@ class CONTENT_EXPORT MediaStreamAudioProcessor :
// Flag to avoid executing Stop() more than once.
bool stopped_;
// Object for logging echo information when the AEC is enabled. Accessible by
// the libjingle thread through GetStats().
std::unique_ptr<EchoInformation> echo_information_;
DISALLOW_COPY_AND_ASSIGN(MediaStreamAudioProcessor);
« no previous file with comments | « no previous file | content/renderer/media/media_stream_audio_processor.cc » ('j') | no next file with comments »
@@ -205,8 +212,8 @@ class CONTENT_EXPORT MediaStreamAudioProcessor :
// Flag to avoid executing Stop() more than once.
bool stopped_;
- // Object for logging echo information when the AEC is enabled. Accessible by
- // the libjingle thread through GetStats().
+ // Object for logging UMA stats for echo information when the AEC is enabled.
+ // Accessed on the main render thread.
std::unique_ptr<EchoInformation> echo_information_;
DISALLOW_COPY_AND_ASSIGN(MediaStreamAudioProcessor);

Powered by Google App Engine
This is Rietveld 408576698